==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/RadialAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialAreaSeriesDescription } from "./RadialAreaSeriesDescription";
/**
 * @hidden
 */
export let RadialAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RadialAreaSeriesDescriptionMetadata.a == null) {
                RadialAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialAreaSeriesDescriptionMetadata.c(RadialAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(RadialAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(RadialAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredRadialSeriesDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            RadialAreaSeriesDescriptionMetadata.b(a);
            a.aa("RadialAreaSeries", () => new RadialAreaSeriesDescription());
            a.z("RadialAreaSeries", RadialAreaSeriesDescriptionMetadata.a);
        }
    }
    RadialAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RadialAreaSeriesDescriptionMetadata, 'RadialAreaSeriesDescriptionMetadata');
    RadialAreaSeriesDescriptionMetadata.a = null;
    return RadialAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RadialAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialAreaSeriesDescription } from "./RadialAreaSeriesDescription";
/**
 * @hidden
 */
export let RadialAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RadialAreaSeriesDescriptionMetadata.a == null) {
                RadialAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialAreaSeriesDescriptionMetadata.c(RadialAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(RadialAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(RadialAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredRadialSeriesDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            RadialAreaSeriesDescriptionMetadata.b(a);
            a.ac("RadialAreaSeries", () => new RadialAreaSeriesDescription());
            a.ab("RadialAreaSeries", RadialAreaSeriesDescriptionMetadata.a);
        }
    }
    RadialAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RadialAreaSeriesDescriptionMetadata, 'RadialAreaSeriesDescriptionMetadata');
    RadialAreaSeriesDescriptionMetadata.a = null;
    return RadialAreaSeriesDescriptionMetadata;
})();
